<?php
//v1.0 www.exoops.info 2006/05 GPL
if ( !preg_match("/admin\.php/i", _PHP_SELF) ) {
	exit();
	}
include_once(XOOPS_ROOT_PATH."/modules/system/admin/mimes/mimes.php");
switch($op) {
	case "MimeAdmin":
		MimeAdmin();
		break;
	case "MimeAdd":
		MimeAdd($mime,$extension);
		break;
		
	case "MimeAddSample":
		MimeAddSample($mime,$extension);
		break;
	case "MimeEdit":
		MimeEdit($id);
		break;
	case "MimeSave":
		MimeSave($id,$mime,$extension);
		break;
	case "MimeDel":
		MimeDel($id, $ok);
		break;
	default:
		MimeAdmin();
		break;
}
?>
